IsContainer

Trait IsContainer 

pub trait IsContainer: Instance { }
Trait indicating that an entity is a container.

Implementors of IsContainer are considered to be container types, which can hold zero or more elements. This trait is typically used in conjunction with reflection mechanisms to dynamically inspect, access, or modify the contents of a container at runtime.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<K: IsScalar + Clone + 'static, V: Instance + 'static> IsContainer for HashMap<K, V>
where Primitive: From<K>,

Source

impl<T: Instance + 'static> IsContainer for Vec<T>

Source

impl<T: Instance + 'static, const N: usize> IsContainer for [T; N]

Source

impl<T: Instance> IsContainer for &'static [T]

Source

impl<V: Instance + 'static> IsContainer for HashSet<V>

Implementors